/*************************************************************
 * spis_main.c
 *
 * SPI slave main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_SPI_SLAVE
#include <string.h>

#include <mux_api.h>
#include <spi_api.h>
#include <spi_main.h>
#include <port_api.h>


// send data number
#define SPI_SLV_MAIN_SENDDATA		"FROM SLV"
#define SPI_SLV_MAIN_SENDDATA_NUM	8
#define SPI_SLV_MAIN_RECVDATA_NUM	8

#define I2C_SLV_MAIN_CH			SPI_CH0				// SPI ch

#define SPI_SLV_MAIN_CS_NEGATE		0xFF		// SS negate
#define SPI_SLV_MAIN_CS_ASSERT		0xBF		// SS assert

// prototype
void spiSlaveMain(void);
static void startSPISlave(unsigned char chNo);
static void stopSPISlave(unsigned char chNo);
static unsigned char sendSPIDataSlave(unsigned char chNo, unsigned char *buf, unsigned char len);

extern unsigned char recvSPIData(unsigned char chNo, unsigned char *buf, unsigned char len);

/*
 * SPI slave sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void spiSlaveMain(void)
{
	unsigned char	spiSlaveSendData[] = SPI_SLV_MAIN_SENDDATA;	// send data charactors
	unsigned char	data[SPI_SLV_MAIN_RECVDATA_NUM + 1];		// receive length

	printf("<<< SPI slave demonstration start >>>\n");

	// start SPI slave
	startSPISlave(I2C_SLV_MAIN_CH);

	printf("Received data: ");

	// receive data from SPI master
	recvSPIData(I2C_SLV_MAIN_CH, &data[0], SPI_SLV_MAIN_RECVDATA_NUM);

	printf("Transmitted data: ");

	// send data to SPI master
	sendSPIDataSlave(I2C_SLV_MAIN_CH, &spiSlaveSendData[0], (unsigned char)strlen((char*)&spiSlaveSendData[0]));

	printf("\n");

	// stop SPI slave
	stopSPISlave(I2C_SLV_MAIN_CH);

	// clear port
	MUX_setSPIport(I2C_SLV_MAIN_CH, MUX_OFF);

	printf("<<< SPI slave demonstration finish >>>\n");
}

/*
 * start SPI slave.
 * param	SPI slave channel number.
 * return	void
 * history	:	2009/12/25
 */
static void startSPISlave(unsigned char chNo)
{
	SPI_INIT_PARAM		param;											// initialize parameter

	param.selectClk			= SPI_CLK_PCLK;
	param.selectMLSB		= SPI_MSB_FIRST;
	param.selectPhase		= SPI_PHASE_DATAIN;
	param.selectPolarity	= SPI_ACTIVE_L;
	param.selectMode		= SPI_MODE_SLAVE;
	SPI_init(chNo, &param);

	SPI_initInt(chNo, SPI_INT_LEVEL3);
	SPI_setComEnable(chNo, SPI_CTL_ENABLE);
}

/*
 * stop SPI slave.
 * param	SPI slave channel number.
 * return	void
 * history	:	2009/12/25
 */
static void stopSPISlave(unsigned char chNo)
{
	SPI_setComEnable(chNo, SPI_CTL_DISABLE);
	SPI_initInt(chNo, SPI_INT_LEVEL0);
}

/*
 * start SPI slave data send.
 * param: unsigned char chNo						SPI channel number.
 * param: unsigned char *buf						send data
 * param: unsigned char len							send data length
 * return: unsigned char							actual send data length
 * history:	2009/12/25
 */
static unsigned char sendSPIDataSlave(unsigned char chNo, unsigned char *buf, unsigned char len)
{
	unsigned char	actual;												// actual send data length
	unsigned short	flgIntr;											// interrupt flag
	SPI_MAIN_PARAM	param;												// SPI parameter


	actual = 0;
	param.dataTx = buf;
	param.counterTx = len;

	// wait all data is sent
	while(param.counterTx > 0) {
		// get interrupt flag
		SPI_checkIntFlag(chNo, &flgIntr);

		if((flgIntr & SPI_TXFLAG_EMPTY) == SPI_TXFLAG_EMPTY) {			//SPI_TXFLAG_EMPTY = 0x01
			if(param.counterTx > 0) {
				// set data
				SPI_setTransmitData(chNo, *param.dataTx);
				param.counterTx--;
				param.dataTx++;
			}
		}
	}

	actual = (unsigned char)(len - param.counterTx);
	printf("%s\n", (param.dataTx - actual));

	return actual;
}

#endif	// end of PE_SPI_SLAVE
