/*************************************************************
 * t8osc1_main.c
 *
 * 8-bit OSC1 timer main module
 *
 * Copyright (C)SEIKO EPSON CORPORATION 2009. All rights reserved.
 ************************************************************/

#include <stdio.h>
#include <s1c176xx.h>

#ifdef	PE_T8OSC1
#include <t8osc1_api.h>
#include <osc_api.h>

#define	T8O_MAIN_LOOP_CT_MAX	10			// loop counter max
#define T8O_GET_COUNT_VAL		10			// frequency of get the counter value
#define T8O_COMPARE_DATA		0xff		//compare data

static unsigned char	t8ObufCounter[T8O_MAIN_LOOP_CT_MAX] = {0};	// counter record buffer
static volatile unsigned char	t8OloopCt;									// loop counter


/* prototype */
void t8osc1Main(void);
static void startT8O(void);
static void stopT8O(void);
void t8oIntHandler(void)__attribute__ ((interrupt_handler));
void t8oSetCallBackFunc(void(*name)(void));
void t8oClearCallBackFunc(void);

static void (*callBackFunction)(void) = 0;		// call back function

/*
 * T8O timer sample program
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t8osc1Main(void)
{
	printf("<<< T8OSC1 timer demonstration start >>>\n");

	// start T8OSC1
	startT8O();

	// T8OSC1 clock output enable
	CLG_OSC_controlT8OSC1(CLG_OSC_T8OSC1_ENABLE);

	t8OloopCt = 0;
	while(t8OloopCt < T8O_MAIN_LOOP_CT_MAX) {
		asm( "halt" );
		asm( "nop" );
		t8OloopCt++;
	}

	// T8OSC1 clock output disable
	CLG_OSC_controlT8OSC1(CLG_OSC_T8OSC1_DISABLE);

	// stop T8OSC1 timer
	stopT8O();

	// output result
	t8OloopCt = 0;
	while(t8OloopCt < T8O_MAIN_LOOP_CT_MAX) {
		t8OloopCt++;
		printf("T8OSC1 interrupt %d time, count data at this time : %d\n", t8OloopCt, t8ObufCounter[t8OloopCt - 1U]);
	}

	printf("<<< T8OSC1 timer demonstration finish >>>\n");
}

/*
 * start T8O timer.
 * param	void.
 * return	void
 * history	:	2009/12/25
 */
static void startT8O(void)
{
	T8O_init(T8O_TIMMODE_REPEAT, CLG_OSC_T8OSC1CLK_1, T8O_COMPARE_DATA);

	T8O_initInt(T8O_INT_LEVEL3);
	T8O_controlInt(T8O_INT_ENABLE);
	T8O_setTimerRun(T8O_TIMER_RUN);
}


/*
 * stop T8O timer.
 * param	void.
 * return	void
 * history	:	2009/12/25
 */
static void stopT8O(void)
{
	T8O_setTimerRun(T8O_TIMER_STOP);
	T8O_controlInt(T8O_INT_DISABLE);
	T8O_initInt(T8O_INT_LEVEL0);
}


/*
 * T8O interrupt handler
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t8oIntHandler(void)
{
	if(callBackFunction != 0) {
		callBackFunction();			// call back
	} else {
		// reset interrupt flag
		T8O_resetIntFlag();

		if (t8OloopCt < T8O_MAIN_LOOP_CT_MAX) {
			T8O_getCounterData(&t8ObufCounter[t8OloopCt], T8O_GET_COUNT_VAL);
		}
	}
}

/*
 * set interrupt call back function.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t8oSetCallBackFunc(void(*name)(void))
{
	callBackFunction = name;
}

/*
 * clear interrupt call back function.
 * param	void
 * return	void
 * history	:	2009/12/25
 */
void t8oClearCallBackFunc(void)
{
	callBackFunction = 0;
}

#endif	// end of PE_T8OSC1
