/******************************************************************
 * ct_api.h
 * 
 * clock timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef CT_API_H_
#define CT_API_H_

#include <ct.h>

/******************************************
 * definition of "define"
 ******************************************/

// clock timer driver return code.
#define	CT_SUCCESS					 0								// success
#define	CT_INVALID_PARAMETER		-1								// invalid parameter
#define	CT_FAILURE					-2								// failure

// clock timer interrupt level.
enum {
	CT_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	CT_INT_LEVEL1,													// 0x01:interrupt level 1
	CT_INT_LEVEL2,													// 0x02:interrupt level 2
	CT_INT_LEVEL3,													// 0x03:interrupt level 3
	CT_INT_LEVEL4,													// 0x04:interrupt level 4
	CT_INT_LEVEL5,													// 0x05:interrupt level 5
	CT_INT_LEVEL6,													// 0x06:interrupt level 6
	CT_INT_LEVEL7,													// 0x07:interrupt level 7

	CT_INT_LEVELMAX
};

// clock timer run / stop control.
#define	CT_TIMER_STOP				CT_STOP							// timer stop
#define	CT_TIMER_RUN				CT_RUN							//		 run

// clock timer counter value.
#define	CT_COUNTER_1				CT1HZ							// counter value : 1Hz
#define	CT_COUNTER_2				CT2HZ							//				 : 2Hz
#define	CT_COUNTER_4				CT4HZ							//				 : 4Hz
#define	CT_COUNTER_8				CT8HZ							//				 : 8Hz
#define	CT_COUNTER_16				CT16HZ							//				 : 16Hz
#define	CT_COUNTER_32				CT32HZ							//				 : 32Hz
#define	CT_COUNTER_64				CT64HZ							//				 : 64Hz
#define	CT_COUNTER_128				CT128HZ							//				 : 128Hz

// clock timer interrupt.
#define	CT_32INT_DISABLE			(CTIE32*CT_DISABLE)				// 32Hz interrupt disable
#define	CT_32INT_ENABLE				(CTIE32*CT_ENABLE)				//				  enable
#define	CT_8INT_DISABLE				(CTIE8*CT_DISABLE)				//  8Hz interrupt disable
#define	CT_8INT_ENABLE				(CTIE8*CT_ENABLE)				//				  enable
#define	CT_2INT_DISABLE				(CTIE2*CT_DISABLE)				//  2Hz interrupt disable
#define	CT_2INT_ENABLE				(CTIE2*CT_ENABLE)				//				  enable
#define	CT_1INT_DISABLE				(CTIE1*CT_DISABLE)				//  1Hz interrupt disable
#define	CT_1INT_ENABLE				(CTIE1*CT_ENABLE)				//				  enable

// clock timer interrupt flag.
#define	CT_32INT_RESET				(CTIF32*CT_RESET)				// 32Hz flag reset
#define	CT_8INT_RESET				(CTIF8*CT_RESET)				//  8Hz flag reset
#define	CT_2INT_RESET				(CTIF2*CT_RESET)				//  2Hz flag reset
#define	CT_1INT_RESET				(CTIF1*CT_RESET)				//  1Hz flag reset

#define	CT_32INT_NOTOCCURRED		(CTIF32*CT_NOTOCCURRED)			// 32Hz not occurred
#define	CT_32INT_OCCURRED			(CTIF32*CT_OCCURRED)			//			occurred
#define	CT_8INT_NOTOCCURRED			(CTIF8*CT_NOTOCCURRED)			//  8Hz not occurred
#define	CT_8INT_OCCURRED			(CTIF8*CT_OCCURRED)				//			occurred
#define	CT_2INT_NOTOCCURRED			(CTIF2*CT_NOTOCCURRED)			//  2Hz not occurred
#define	CT_2INT_OCCURRED			(CTIF2*CT_OCCURRED)				//			occurred
#define	CT_1INT_NOTOCCURRED			(CTIF1*CT_NOTOCCURRED)			//  1Hz not occurred
#define	CT_1INT_OCCURRED			(CTIF1*CT_OCCURRED)				//			occurred


/******************************************
 * Declarations of function prototype
 ******************************************/
extern void CT_resetTimer(void);
extern short CT_setTimerRun(unsigned char selectBit);
extern short CT_getCounterData(unsigned char *data, unsigned char number);
extern short CT_initInt(unsigned char intLevel);
extern short CT_controlInt(unsigned char selectBit);
extern short CT_resetIntFlag(unsigned char selectBit);
extern void CT_checkIntFlag(unsigned char *flag);


#endif	// end of CT_API_H_
