/******************************************************************
 * rfc_api.h
 *
 * RFC driver
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef RFC_API_H_
#define RFC_API_H_

#include <rfc.h>

/******************************************
 * definition of "define"
 ******************************************/

// RFC driver return code.
#define	RFC_SUCCESS					 0								// success
#define	RFC_INVALID_PARAMETER		-1								// invalid parameter
#define	RFC_FAILURE					-2								// failure

// RFC interrupt level.
enum {
	RFC_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	RFC_INT_LEVEL1,													// 0x01:interrupt level 1
	RFC_INT_LEVEL2,													// 0x02:interrupt level 2
	RFC_INT_LEVEL3,													// 0x03:interrupt level 3
	RFC_INT_LEVEL4,													// 0x04:interrupt level 4
	RFC_INT_LEVEL5,													// 0x05:interrupt level 5
	RFC_INT_LEVEL6,													// 0x06:interrupt level 6
	RFC_INT_LEVEL7,													// 0x07:interrupt level 7

	RFC_INT_LEVELMAX
};

// channel number.
enum {
	RFC_CH0 = 0,													// 0x00 : channel 0
#ifndef	RFC_CHANNEL1
	RFC_CH1,														// 0x01 : channel 1
#endif	// end of RFC_CHANNEL1

	RFC_CH_MAX
};

// channel number.
#define	RFC_CONVERSION_CH0			RFC_CH0							// channel 0
#ifndef	RFC_CHANNEL1
#define	RFC_CONVERSION_CH1			RFC_CH1							// channel 1
#endif	// end of RFC_CHANNEL1

// RFC enable / disable.
#define	RFC_DISABLE					RFC_BIT_DISABLE					// RFC disable
#define	RFC_ENABLE					RFC_BIT_ENABLE					//	   enable

// sensor oscillation mode.
enum {
	RFC_OSCMODE_RDC = 0,											// 0x00 : sensor oscillation mode : RDC
	RFC_OSCMODE_RAC,												// 0x01 : 						  : RAC
	RFC_OSCMODE_CDC,												// 0x02 : 						  : CDC

	RFC_OSCMODE_MAX
};

// RFC oscillation.
#define	RFC_SENBOSC_STOP			RFC_STOP						// sensor B oscillation stop
#define	RFC_SENBOSC_START			RFC_START						//						start
#define	RFC_SENBOSC_RUN				RFC_RUN							//						run
#define	RFC_SENAOSC_STOP			RFC_STOP						// sensor A oscillation stop
#define	RFC_SENAOSC_START			RFC_START						//						start
#define	RFC_SENAOSC_RUN				RFC_RUN							//						run
#define	RFC_REFOSC_STOP				RFC_STOP						// reference oscillation stop
#define	RFC_REFOSC_START			RFC_START						//						 start
#define	RFC_REFOSC_RUN				RFC_RUN							//						 run

// RFC select function.
#define	RFC_EVTMODE_DISABLE			RFC_BIT_DISABLE					// event counter mode disable
#define	RFC_EVTMODE_ENABLE			RFC_BIT_ENABLE					//					  enable
#define	RFC_CONTINUOUS_DISABLE		RFC_BIT_DISABLE					// continuous oscillation disable
#define	RFC_CONTINUOUS_ENABLE		RFC_BIT_ENABLE					//						  enable

// RFC interrupt.
#define	RFC_TCOVFINT_DISABLE		(OVTCIE*RFC_DISABLE)			// timer base counter over flow error interrupt disable
#define	RFC_TCOVFINT_ENABLE			(OVTCIE*RFC_ENABLE)				//												enable
#define	RFC_MCOVFINT_DISABLE		(OVMCIE*RFC_DISABLE)			// measurement counter over flow error interrupt disable
#define	RFC_MCOVFINT_ENABLE			(OVMCIE*RFC_ENABLE)				//												 enable
#define	RFC_SENBINT_DISABLE			(ESENBIE*RFC_DISABLE)			// sensor B oscillation end interrupt disable
#define	RFC_SENBINT_ENABLE			(ESENBIE*RFC_ENABLE)			//									  enable
#define	RFC_SENAINT_DISABLE			(ESENAIE*RFC_DISABLE)			// sensor A oscillation end interrupt disable
#define	RFC_SENAINT_ENABLE			(ESENAIE*RFC_ENABLE)			//									  enable
#define	RFC_REFINT_DISABLE			(EREFIE*RFC_DISABLE)			// reference oscillation end interrupt disable
#define	RFC_REFINT_ENABLE			(EREFIE*RFC_ENABLE)				//									   enable

// RFC interrupt flag.
#define	RFC_TCOVFINT_RESET			(OVTCIF*RFC_RESET)				// timer base counter over flow error flag reset
#define	RFC_MCOVFINT_RESET			(OVMCIF*RFC_RESET)				// measurement counter over flow error flag reset
#define	RFC_SENBINT_RESET			(ESENBIF*RFC_RESET)				// sensor B oscillation end flag reset
#define	RFC_SENAINT_RESET			(ESENAIF*RFC_RESET)				// sensor A oscillation end flag reset
#define	RFC_REFINT_RESET			(EREFIF*RFC_RESET)				// reference oscillation end flag reset

#define	RFC_TCOVFINT_NOTOCCURRED	(OVTCIF*RFC_NOTOCCURRED)		// timer base counter over flow error interrupt not occurred
#define	RFC_TCOVFINT_OCCURRED		(OVTCIF*RFC_OCCURRED)			//												occurred
#define	RFC_MCOVFINT_NOTOCCURRED	(OVMCIF*RFC_NOTOCCURRED)		// measurement counter over flow error interrupt not occurred
#define	RFC_MCOVFINT_OCCURRED		(OVMCIF*RFC_OCCURRED)			//												 occurred
#define	RFC_SENBINT_NOTOCCURRED		(ESENBIF*RFC_NOTOCCURRED)		// sensor B oscillation end interrupt not occurred
#define	RFC_SENBINT_OCCURRED		(ESENBIF*RFC_OCCURRED)			//									  occurred
#define	RFC_SENAINT_NOTOCCURRED		(ESENAIF*RFC_NOTOCCURRED)		// sensor A oscillation end interrupt not occurred
#define	RFC_SENAINT_OCCURRED		(ESENAIF*RFC_OCCURRED)			//									  occurred
#define	RFC_REFINT_NOTOCCURRED		(EREFIF*RFC_NOTOCCURRED)		// reference oscillation end interrupt not occurred
#define	RFC_REFINT_OCCURRED			(EREFIF*RFC_OCCURRED)			//									   occurred


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short RFC_setRFC(unsigned char selectBit);
extern short RFC_setRFCChannel(unsigned char selectBit);
extern short RFC_setRFCMode(unsigned char selectBit);
extern short RFC_setReferenceOscillation(unsigned char selectBit);
extern short RFC_setSensorAOscillation(unsigned char selectBit);
extern short RFC_setSensorBOscillation(unsigned char selectBit);
extern void RFC_getReferenceOscillation(unsigned char *condition);
extern void RFC_getSensorAOscillation(unsigned char *condition);
extern void RFC_getSensorBOscillation(unsigned char *condition);
extern short RFC_setEventMode(unsigned char selectBit);
extern short RFC_setContinuous(unsigned char selectBit);
extern short RFC_setMeasurementCounter(unsigned long counter);
extern short RFC_setTimeBaseCounter(unsigned long counter);
extern void RFC_getMeasurementCounter(unsigned long *counter);
extern void RFC_getTimeBaseCounter(unsigned long *counter);
extern short RFC_initInt(unsigned char intLevel);
extern short RFC_controlInt(unsigned char selectBit);
extern short RFC_resetIntFlag(unsigned char selectBit);
extern void RFC_checkIntFlag(unsigned char *flag);


#endif	// end of RFC_API_H_
