/******************************************************************
 * spi_api.h
 * 
 * SPI driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef SPI_API_H_
#define SPI_API_H_

#include <spi.h>

/******************************************
 * definition of "define"
 ******************************************/

// SPI driver return code.
#define	SPI_SUCCESS					 0								// success
#define	SPI_INVALID_PARAMETER		-1								// invalid parameter
#define	SPI_FAILURE					-2								// failure

// SPI interrupt level.
enum {
	SPI_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	SPI_INT_LEVEL1,													// 0x01:interrupt level 1
	SPI_INT_LEVEL2,													// 0x02:interrupt level 2
	SPI_INT_LEVEL3,													// 0x03:interrupt level 3
	SPI_INT_LEVEL4,													// 0x04:interrupt level 4
	SPI_INT_LEVEL5,													// 0x05:interrupt level 5
	SPI_INT_LEVEL6,													// 0x06:interrupt level 6
	SPI_INT_LEVEL7,													// 0x07:interrupt level 7

	SPI_INT_LEVELMAX
};

// channel number.
enum {
	SPI_CH0 = 0,													// 0x00 : channel 0
#ifndef	SPI_CHANNEL1
	SPI_CH1,														// 0x01 : channel 1
	SPI_CH2,														// 0x02 : channel 2
#endif	// end of SPI_CHANNEL1
	
	SPI_CH_MAX
};

// SPI initialize parameter.
#define	SPI_CLK_PCLK				SPI_PCLK						// select SPI clock source : PCLK1/4
#define	SPI_CLK_T16					SPI_T16							//						   : T16 ch1
#define	SPI_MSB_FIRST				SPI_MSB							// select MSB first
#define	SPI_LSB_FIRST				SPI_LSB							// select LSB first
#define	SPI_PHASE_DATAIN			SPI_DATA_IN						// select SPI clock phase : data in
#define	SPI_PHASE_DATAOUT			SPI_DATA_OUT					//						  : data out
#define	SPI_ACTIVE_H				SPI_ACTH						// select SPI clock polarity : active H
#define	SPI_ACTIVE_L				SPI_ACTL						//							 : active L
#define	SPI_MODE_SLAVE				SPI_SLAVE						// select slave mode
#define	SPI_MODE_MASTER				SPI_MASTER						// select master mode

// SPI enable / disable.
#define	SPI_CTL_DISABLE				SPI_DISABLE						// SPI disable
#define	SPI_CTL_ENABLE				SPI_ENABLE						//	   enable

// SPI interrupt.
#define	SPI_RXINT_DISABLE			(SPRIE*SPI_DISABLE)				// receive buffer full interrupt disable
#define	SPI_RXINT_ENABLE			(SPRIE*SPI_ENABLE)				//								 enable
#define	SPI_TXINT_DISABLE			(SPTIE*SPI_DISABLE)				// transmit buffer empty interrupt disable
#define	SPI_TXINT_ENABLE			(SPTIE*SPI_ENABLE)				//								   enable

// SPI interrupt flag.
#define	SPI_RXFLAG_NOTFULL			(SPRBF*SPI_NOTFULL)				// receive data buffer not full
#define	SPI_RXFLAG_FULL				(SPRBF*SPI_FULL)				//					   full
#define	SPI_TXFLAG_NOTEMPTY			(SPTBE*SPI_NOTEMPTY)			// transmit data buffer not empty
#define	SPI_TXFLAG_EMPTY			(SPTBE*SPI_EMPTY)				//						empty

// SPI flag.
#define	SPI_BUSYFLAG_IDLE			(SPBSY*SPI_IDLE)				// transfer idle
#define	SPI_BUSYFLAG_BUSY			(SPBSY*SPI_BUSY)				// transfer busy
#define	SPI_SSFLAG_H				(SPBSY*SPI_SSH)					// ss signal high
#define	SPI_SSFLAG_L				(SPBSY*SPI_SSL)					// ss signal low


/******************************************
 * definition of "struct"
 ******************************************/

// SPI initialize parameter.
struct tag_SPI_INIT_PARAM;
typedef struct tag_SPI_INIT_PARAM {
	unsigned short	selectClk;										// select SPI clock source
	unsigned short	selectMLSB;										// select LSB/MSB first mode
	unsigned short	selectPhase;									// select SPI clock phase
	unsigned short	selectPolarity;									// select SPI clock polarity
	unsigned short	selectMode;										// select master/slave mode
} SPI_INIT_PARAM;


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short SPI_init(unsigned char chNo, SPI_INIT_PARAM *param);
extern short SPI_setTransmitData(unsigned char chNo, unsigned char data);
extern short SPI_getReceiveData(unsigned char chNo, unsigned char *data);
extern short SPI_setComEnable(unsigned char chNo, unsigned short selectBit);
extern short SPI_initInt(unsigned char chNo, unsigned char intLevel);
extern short SPI_controlInt(unsigned char chNo, unsigned short selectBit);
extern short SPI_checkIntFlag(unsigned char chNo, unsigned short *flag);
extern short SPI_checkBusyFlag(unsigned char chNo, unsigned short *flag);


#endif	// end of SPI_API_H_
