/******************************************************************
 * swt_api.h
 * 
 * stopwatch timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef SWT_API_H_
#define SWT_API_H_

#include <swt.h>

/******************************************
 * definition of "define"
 ******************************************/

// stopwatch timer driver return code.
#define	SWT_SUCCESS					 0								// success
#define	SWT_INVALID_PARAMETER		-1								// invalid parameter
#define	SWT_FAILURE					-2								// failure

// stopwatch timer interrupt level.
enum {
	SWT_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	SWT_INT_LEVEL1,													// 0x01:interrupt level 1
	SWT_INT_LEVEL2,													// 0x02:interrupt level 2
	SWT_INT_LEVEL3,													// 0x03:interrupt level 3
	SWT_INT_LEVEL4,													// 0x04:interrupt level 4
	SWT_INT_LEVEL5,													// 0x05:interrupt level 5
	SWT_INT_LEVEL6,													// 0x06:interrupt level 6
	SWT_INT_LEVEL7,													// 0x07:interrupt level 7

	SWT_INT_LEVELMAX
};

// stopwatch timer run / stop control.
#define	SWT_TIMER_STOP				SWT_STOP						// timer stop
#define	SWT_TIMER_RUN				SWT_RUN							//		 run

// stopwatch timer BCD counter value.
#define	SWT_DATA_BCD10				BCD10							// 1/ 10 sec. BCD counter value
#define	SWT_DATA_BCD100				BCD100							// 1/100 sec. BCD counter value

// stopwatch timer interrupt.
#define	SWT_1INT_DISABLE			(SIE1*SWT_DISABLE)				//   1Hz interrupt disable
#define	SWT_1INT_ENABLE				(SIE1*SWT_ENABLE)				//				   enable
#define	SWT_10INT_DISABLE			(SIE10*SWT_DISABLE)				//  10Hz interrupt disable
#define	SWT_10INT_ENABLE			(SIE10*SWT_ENABLE)				//				   enable
#define	SWT_100INT_DISABLE			(SIE100*SWT_DISABLE)			// 100Hz interrupt disable
#define	SWT_100INT_ENABLE			(SIE100*SWT_ENABLE)				//				   enable

// stopwatch timer interrupt flag.
#define	SWT_1INT_RESET				(SIF1*SWT_RESET)				//   1Hz flag reset
#define	SWT_10INT_RESET				(SIF10*SWT_RESET)				//  10Hz flag reset
#define	SWT_100INT_RESET			(SIF100*SWT_RESET)				// 100Hz flag reset

#define	SWT_1INT_NOTOCCURRED		(SIF1*SWT_NOTOCCURRED)			//   1Hz not occurred
#define	SWT_1INT_OCCURRED			(SIF1*SWT_OCCURRED)				//			 occurred
#define	SWT_10INT_NOTOCCURRED		(SIF10*SWT_NOTOCCURRED)			//  10Hz not occurred
#define	SWT_10INT_OCCURRED			(SIF10*SWT_OCCURRED)			//			 occurred
#define	SWT_100INT_NOTOCCURRED		(SIF100*SWT_NOTOCCURRED)		// 100Hz not occurred
#define	SWT_100INT_OCCURRED			(SIF100*SWT_OCCURRED)			//			 occurred


/******************************************
 * Declarations of function prototype
 ******************************************/
extern void SWT_resetTimer(void);
extern short SWT_setTimerRun(unsigned char selectBit);
extern short SWT_getCounterDataBCD(unsigned char *data, unsigned char number);
extern short SWT_initInt(unsigned char intLevel);
extern short SWT_controlInt(unsigned char selectBit);
extern short SWT_resetIntFlag(unsigned char selectBit);
extern void SWT_checkIntFlag (unsigned char *flag);


#endif	// end of SWT_API_H_
