/******************************************************************
 * t8osc1_api.h
 * 
 * 8-bit OSC1 timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef T8O_API_H_
#define T8O_API_H_

#include <t8osc1.h>

/******************************************
 * definition of "define"
 ******************************************/

// 8-bit OSC1 timer driver return code.
#define	T8O_SUCCESS					 0								// success
#define	T8O_INVALID_PARAMETER		-1								// invalid parameter
#define	T8O_FAILURE					-2								// failure

// 8-bit OSC1 timer interrupt level.
enum {
	T8O_INT_LEVEL0 = 0x00,											// 0x00:interrupt level 0
	T8O_INT_LEVEL1,													// 0x01:interrupt level 1
	T8O_INT_LEVEL2,													// 0x02:interrupt level 2
	T8O_INT_LEVEL3,													// 0x03:interrupt level 3
	T8O_INT_LEVEL4,													// 0x04:interrupt level 4
	T8O_INT_LEVEL5,													// 0x05:interrupt level 5
	T8O_INT_LEVEL6,													// 0x06:interrupt level 6
	T8O_INT_LEVEL7,													// 0x07:interrupt level 7

	T8O_INT_LEVELMAX
};

// 8-bit OSC1 timer mode set parameter.
#define	T8O_TIMMODE_REPEAT			T8O_REPEAT						// select count mode : repeat
#define	T8O_TIMMODE_ONESHOT			T8O_ONESHOT						//					 : one shot

// 8-bit OSC1 timer run / stop control.
#define	T8O_TIMER_STOP				T8O_STOP						// timer stop
#define	T8O_TIMER_RUN				T8O_RUN							//		 run

// 8-bit OSC1 timer interrupt.
#define	T8O_INT_DISABLE				T8O_DISABLE						// interrupt disable
#define	T8O_INT_ENABLE				T8O_ENABLE						//			 enable

// 8-bit OSC1 timer interrupt flag.
#define	T8O_TIMERINT_NOTOCCURRED	T8O_NOTOCCURRED					// not occurred
#define	T8O_TIMERINT_OCCURRED		T8O_OCCURRED					// occurred


/******************************************
 * Declarations of function prototype
 ******************************************/
extern short T8O_init(unsigned char mode, unsigned char selectBit, unsigned char data);
extern void T8O_resetTimer(void);
extern short T8O_setTimerMode(unsigned char mode);
extern short T8O_setTimerRun(unsigned char selectBit);
extern short T8O_getCounterData(unsigned char *data, unsigned char number);
extern void T8O_setCompareData(unsigned char data);
extern short T8O_initInt(unsigned char intLevel);
extern short T8O_controlInt(unsigned char selectBit);
extern void T8O_resetIntFlag(void);
extern void T8O_checkIntFlag(unsigned char *flag);
extern void T8O_setPWMOut(unsigned char data);


#endif	// end of T8O_API_H_
