/**
 * @file	clg.c
 * @brief	CLG driver
 * 
 * - Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 */

#include <s1c176xx.h>

#ifdef	PE_CLG
#include	<clg_api.h>

/*
 * definition of "define"
 */


/*
 * definition of constants
 */


/*
 * Declarations of function prototype
 */
short CLG_setPCLKEnable(unsigned char selectBit);
short CLG_setCCLKGearRatio(unsigned char selectBit);


/**
 * @brief	set a PCLK supply enable / disable.
 * - 1. check parameters.
 * - 2. set a PCLK supply enable/disable.
 *
 * @param	selectBit; unsigned char: 		select enable / disable
 * -		CLG_PCLK_DISABLE : PCLK supply disable
 * -		CLG_PCLK_ENABLE  : PCLK supply enable
 * @return	short:							end status
 * -		CLG_SUCCESS : success
 * -		CLG_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short CLG_setPCLKEnable(unsigned char selectBit)
{
	// parameter check
	if(	(selectBit != CLG_PCLK_ENABLE) &&
		(selectBit != CLG_PCLK_DISABLE) ) {
			return	CLG_INVALID_PARAMETER;
	}
	
	// PCLK enable / disable set
	RegWrite(R08_CLG_PCLK, selectBit);
	
	return	CLG_SUCCESS;
}

/**
 * @brief	set a CCLK gear ratio.
 * - 1. check parameters.
 * - 2. set a CCLK gear ratio.
 *
 * @param	selectBit; unsigned char: 		select gear ratio
 * -		CLG_GEAR_RATIO1 : gear ratio 1/1
 * -		CLG_GEAR_RATIO2 : gear ratio 1/2
 * -		CLG_GEAR_RATIO4 : gear ratio 1/4
 * -		CLG_GEAR_RATIO8 : gear ratio 1/8
 * @return	short:							end status
 * -		CLG_SUCCESS : success
 * -		CLG_INVALID_PARAMETER : invalid parameter
 * @date	2009/12/25
 */
short CLG_setCCLKGearRatio(unsigned char selectBit)
{
	// parameter check
	if(selectBit >= CLG_GEAR_MAX) {
		return	CLG_INVALID_PARAMETER;
	}
	
	// CCLK gear ratio set
	RegWrite(R08_CLG_CCLK, selectBit);
	
	return	CLG_SUCCESS;
}

#endif	// end of PE_CLG
