/******************************************************************
 * remc.h
 * 
 * REMC driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef REMC_H_
#define REMC_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct remc_cfgBitF {
	unsigned int	remen	: 1;
	unsigned int	remmd	: 1;
	unsigned int			: 6;
	unsigned int	lcclk	: 4;
	unsigned int	cgclk	: 4;
};

struct remc_carBitF {
	unsigned int	remch	: 6;
	unsigned int			: 2;
	unsigned int	remcl	: 6;
	unsigned int			: 2;
};

struct remc_lcntBitF {
	unsigned int	remdt	: 1;
	unsigned int			: 7;
	unsigned int	remlen	: 8;
};

struct remc_intBitF {
	unsigned int	remuie	: 1;
	unsigned int	remrie	: 1;
	unsigned int	remfie	: 1;
	unsigned int			: 5;
	unsigned int	remuif	: 1;
	unsigned int	remrif	: 1;
	unsigned int	remfif	: 1;
	unsigned int			: 5;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	REMC_BASE_ADDR						(BASE_ADDR+REMC_OFFSET)


/***********************************************
 ****** The Definition of Remoto Controller ****
 ****** [REMC]                              ****
 ***********************************************/
// REMC Configuration Register
#define	R16_REMC_CFG						(volatile unsigned short *)(unsigned long)(REMC_BASE_ADDR+0x00)
	#define	CGCLK_SFT							12
	#define	LCCLK_SFT							8
	#define	REMMD_SFT							1
	#define	REMEN_SFT							0
	#define	CGCLK								BIT(0x000f, CGCLK_SFT)		// Carrier Generator Clock Select
	#define	LCCLK								BIT(0x000f, LCCLK_SFT)		// Length Counter Clock Select
	#define	REMMD								BIT(0x0001, REMMD_SFT)		// REMC Mode Select
		#define	REMC_TX								0x0000						// transmit
		#define	REMC_RX								0x0001						// receive
	#define	REMEN								BIT(0x0001, REMEN_SFT)		// REMC Enable
		#define	REMC_BIT_DISABLE					0x0000						// disable
		#define	REMC_BIT_ENABLE						0x0001						// enable

#ifdef	BIT_FIELD
#define REMC_CFG							*(volatile unsigned short *)(BASE_ADDR+0x1340)
#define BF_REMC_CFG							(*(volatile struct remc_cfgBitF *)(BASE_ADDR+0x1340))
	#define REMC_CFG_CGCLK						BF_REMC_CFG.cgclk			// Carrier generator clock select
	#define REMC_CFG_LCCLK						BF_REMC_CFG.lcclk			// Length counter clock select
	#define REMC_CFG_REMMD						BF_REMC_CFG.remmd			// REMC mode select
	#define REMC_CFG_REMEN						BF_REMC_CFG.remen			// REMC enable
#endif	// end of BIT_FIELD


// REMC Carrier Length Setup Register
#define	R16_REMC_CAR						(volatile unsigned short *)(unsigned long)(REMC_BASE_ADDR+0x02)
	#define	REMCL_SFT							8
	#define	REMCH_SFT							0
	#define	REMCL								BIT(0x003f, REMCL_SFT)		// L Carrier Length Setup
	#define	REMCH								BIT(0x003f, REMCH_SFT)		// H Carrier Length Setup

#ifdef	BIT_FIELD
#define REMC_CAR							*(volatile unsigned short *)(BASE_ADDR+0x1342)
#define BF_REMC_CAR							(*(volatile struct remc_carBitF *)(BASE_ADDR+0x1342))
	#define REMC_CAR_REMCL						BF_REMC_CAR.remcl			// L carrier length setup
	#define REMC_CAR_REMCH						BF_REMC_CAR.remch			// H carrier length setup
#endif	// end of BIT_FIELD


// REMC Length Counter Register
#define	R16_REMC_LCNT						(volatile unsigned short *)(unsigned long)(REMC_BASE_ADDR+0x04)
	#define	REMLEN_SFT							8
	#define	REMDT_SFT							0
	#define	REMLEN								BIT(0x00ff, REMLEN_SFT)		// Transmit/Receive Data Length Count
		#define	REMC_LENGTH_MAX						0x00ff						// length max
	#define	REMDT								BIT(0x0001, REMDT_SFT)		// Transmit/Receive Data
		#define	REMC_L								0x0000						// low
		#define	REMC_H								0x0001						// high

#ifdef	BIT_FIELD
#define REMC_LCNT							*(volatile unsigned short *)(BASE_ADDR+0x1344)
#define BF_REMC_LCNT						(*(volatile struct remc_lcntBitF *)(BASE_ADDR+0x1344))
	#define REMC_LCNT_REMLEN					BF_REMC_LCNT.remlen			// Transmit/Recieve data length count
	#define REMC_LCNT_REMDT						BF_REMC_LCNT.remdt			// Transmit/Recieve data
#endif	// end of BIT_FIELD


// REMC Interrupt Control Register
#define	R16_REMC_INT						(volatile unsigned short *)(unsigned long)(REMC_BASE_ADDR+0x06)
	#define	REMFIF_SFT							10
	#define	REMRIF_SFT							9
	#define	REMUIF_SFT							8
	#define	REMFIE_SFT							2
	#define	REMRIE_SFT							1
	#define	REMUIE_SFT							0
	#define	REMFIF								BIT(0x0001, REMFIF_SFT)		// Falling Edge Interrupt Flag
	#define	REMRIF								BIT(0x0001, REMRIF_SFT)		// Rising Edge Interrupt Flag
	#define	REMUIF								BIT(0x0001, REMUIF_SFT)		// Underflow Interrupt Flag
		#define	REMC_INVALID						0x0000						// invalid
		#define	REMC_RESET							0x0001						// reset
		#define	REMC_NOTOCCURRED					0x0000						// not occurred
		#define	REMC_OCCURRED						0x0001						// occurred
		#define	REMC_FLG_MASK						(REMFIF | REMRIF | REMUIF)	// interrupt flag mask data
	#define	REMFIE								BIT(0x0001, REMFIE_SFT)		// Falling Edge Interrupt Enable
	#define	REMRIE								BIT(0x0001, REMRIE_SFT)		// Rising Edge Interrupt Enable
	#define	REMUIE								BIT(0x0001, REMUIE_SFT)		// Underflow Interrupt Enable
		#define	REMC_IEN_MASK						(REMFIE | REMRIE | REMUIE)	// interrupt mask data

#ifdef	BIT_FIELD
#define REMC_INT							*(volatile unsigned short *)(BASE_ADDR+0x1346)
#define BF_REMC_INT							(*(volatile struct remc_intBitF *)(BASE_ADDR+0x1346))
	#define REMC_INT_REMFIF						BF_REMC_INT.remfif			// Falling edge interrupt flag
	#define REMC_INT_REMRIF						BF_REMC_INT.remrif			// Raising edge interrupt flag
	#define REMC_INT_REMUIF						BF_REMC_INT.remuif			// Underflow edge interrupt flag
	#define REMC_INT_REMFIE						BF_REMC_INT.remfie			// Falling edge interrupt enable
	#define REMC_INT_REMRIE						BF_REMC_INT.remrie			// Rising edge interrupt enable
	#define REMC_INT_REMUIE						BF_REMC_INT.remuie			// Underflow interrupt enable
#endif	// end of BIT_FIELD


#endif	// end of REMC_H_
