/******************************************************************
 * swt.h
 * 
 * stopwatch timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef SWT_H_
#define SWT_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct swt_ctlBitF {
	unsigned int	swtrun	: 1;
	unsigned int			: 3;
	unsigned int	swtrst	: 1;
	unsigned int			: 3;
};

struct swt_bcntBitF {
	unsigned int	bcd100	: 4;
	unsigned int	bcd10	: 4;
};

struct swt_imskBitF {
	unsigned int	sie100	: 1;
	unsigned int	sie10	: 1;
	unsigned int	sie1	: 1;
	unsigned int			: 5;
};

struct swt_iflgBitF {
	unsigned int	sif100	: 1;
	unsigned int	sif10	: 1;
	unsigned int	sif1	: 1;
	unsigned int			: 5;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	SWT_BASE_ADDR						(BASE_ADDR+SWT_OFFSET)


/***********************************************
 ****** The Definition of Stopwatch Timer ******
 ****** [SWT]                             ******
 ***********************************************/
// Stopwatch Timer Control Register
#define	R08_SWT_CTL							(volatile unsigned char *)(unsigned long)(SWT_BASE_ADDR+0x00)
	#define	SWTRST_SFT							4
	#define	SWTRUN_SFT							0
	#define	SWTRST								BIT(0x01, SWTRST_SFT)		// Stopwatch Timer Reset
		#define	SWT_INVALID							0x00						// invalid
		#define	SWT_RESET							0x01						// reset
	#define	SWTRUN								BIT(0x01, SWTRUN_SFT)		// Stopwatch Timer Run/Stop Control
		#define	SWT_STOP							0x00						// stop
		#define	SWT_RUN								0x01						// run

#ifdef	BIT_FIELD
#define SWT_CTL								*(volatile unsigned char *)(BASE_ADDR+0x1020)
#define BF_SWT_CTL							(*(volatile struct swt_ctlBitF *)(BASE_ADDR+0x1020))
	#define SWT_CTL_SWTRST						BF_SWT_CTL.swtrst			// Stopwatch timer reset
	#define SWT_CTL_SWTRUN						BF_SWT_CTL.swtrun			// Stopwatch timer run/stop control
#endif	// end of BIT_FIELD


// Stopwatch Timer BCD Counter Register
#define	R08_SWT_BCNT						(volatile unsigned char *)(unsigned long)(SWT_BASE_ADDR+0x01)
	#define	BCD10_SFT							4
	#define	BCD100_SFT							0
	#define	BCD10								BIT(0x0f, BCD10_SFT)		// 1/10 Sec. BCD Counter Value
	#define	BCD100								BIT(0x0f, BCD100_SFT)		// 1/100 Sec. BCD Counter Value

#ifdef	BIT_FIELD
#define SWT_BCNT							*(volatile unsigned char *)(BASE_ADDR+0x1021)
#define BF_SWT_BCNT							(*(volatile struct swt_bcntBitF *)(BASE_ADDR+0x1021))
	#define SWT_BCNT_BCD10						BF_SWT_BCNT.bcd10			// 1/10 sec. BCD counter value
	#define SWT_BCNT_BCD100						BF_SWT_BCNT.bcd100			// 1/100 sec. BCD counter value
#endif	// end of BIT_FIELD


// Stopwatch Timer Interruput Mask Register
#define	R08_SWT_IMSK						(volatile unsigned char *)(unsigned long)(SWT_BASE_ADDR+0x02)
	#define	SIE1_SFT							2
	#define	SIE10_SFT							1
	#define	SIE100_SFT							0
	#define	SIE1								BIT(0x01, SIE1_SFT)			// 1 Hz Interrupt Enable
	#define	SIE10								BIT(0x01, SIE10_SFT)		// 10 Hz Interrupt Enable
	#define	SIE100								BIT(0x01, SIE100_SFT)		// 100 Hz Interrupt Enable
		#define	SWT_DISABLE							0x00						// disable
		#define	SWT_ENABLE							0x01						// enable
		#define	SWT_INT_MASK						(SIE1 | SIE10 | SIE100)		// interrupt mask data

#ifdef	BIT_FIELD
#define SWT_IMSK							*(volatile unsigned char *)(BASE_ADDR+0x1022)
#define BF_SWT_IMSK							(*(volatile struct swt_imskBitF *)(BASE_ADDR+0x1022))
	#define SWT_IMSK_SIE1						BF_SWT_IMSK.sie1			// 1 Hz interrupt enable
	#define SWT_IMSK_SIE10						BF_SWT_IMSK.sie10			// 10 Hz interrupt enable
	#define SWT_IMSK_SIE100						BF_SWT_IMSK.sie100			// 100 Hz interrupt enable
#endif	// end of BIT_FIELD


// Stopwatch Timer Interrupt Flag Register
#define	R08_SWT_IFLG						(volatile unsigned char *)(unsigned long)(SWT_BASE_ADDR+0x03)
	#define	SIF1_SFT							2
	#define	SIF10_SFT							1
	#define	SIF100_SFT							0
	#define	SIF1								BIT(0x01, SIF1_SFT)			// 1 Hz Interrupt Flag
	#define	SIF10								BIT(0x01, SIF10_SFT)		// 10 Hz Interrupt Flag
	#define	SIF100								BIT(0x01, SIF100_SFT)		// 100 Hz Interrupt Flag
		#define	SWT_NOTOCCURRED						0x00						// not occurred
		#define	SWT_OCCURRED						0x01						// occurred

#ifdef	BIT_FIELD
#define SWT_IFLG							*(volatile unsigned char *)(BASE_ADDR+0x1023)
#define BF_SWT_IFLG							(*(volatile struct swt_iflgBitF *)(BASE_ADDR+0x1023))
	#define SWT_IFLG_SIF1						BF_SWT_IFLG.sif1			// 1 Hz interrupt flag  (read only)
	#define SWT_IFLG_SIF10						BF_SWT_IFLG.sif10			// 10 Hz interrupt flag  (read only)
	#define SWT_IFLG_SIF100						BF_SWT_IFLG.sif100			// 100 Hz interrupt flag  (read only)
#endif	// end of BIT_FIELD


#endif	// end of SWT_H_
