/******************************************************************
 * t16e.h
 *
 * PWM timer driver
 *
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef T16E_H_
#define T16E_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct t16e_ctlBitF {
	unsigned int	t16erun	: 1;
	unsigned int	t16erst	: 1;
	unsigned int	outen	: 1;
	unsigned int	clksel	: 1;
	unsigned int	invout	: 1;
	unsigned int	cbufen	: 1;
	unsigned int	selfm	: 1;
	unsigned int			: 1;
	unsigned int	initol	: 1;
	unsigned int			: 7;
};

struct t16e_clkBitF {
	unsigned int	t16edf	: 4;
	unsigned int			: 12;
};

struct t16e_imskBitF {
	unsigned int	caie	: 1;
	unsigned int	cbie	: 1;
	unsigned int			: 14;
};

struct t16e_iflgBitF {
	unsigned int	caif	: 1;
	unsigned int	cbif	: 1;
	unsigned int			: 14;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	T16E_BASE_ADDR						(BASE_ADDR+T16E_OFFSET)


/***********************************************
 ****** The Definition of PWM & Capture Timer **
 ****** [T16E]                                **
 ***********************************************/
// PWM Timer Compare Data A Register
#define	R16_T16E_CA(ch)						(volatile unsigned short *)(unsigned long)(T16E_BASE_ADDR+0x00+(ch*T16E_CHOFFSET))

#ifdef	BIT_FIELD
#define T16E_CA0							*(volatile unsigned short *)(BASE_ADDR+0x1300)
	#define T16E_CA0_T16ECA						T16E_CA0					// Compare data A

#ifdef	T16E_CHANNEL2
#define T16E_CA1							*(volatile unsigned short *)(BASE_ADDR+0x1360)
	#define T16E_CA1_T16ECA						T16E_CA1					// Compare data A
#endif	// end of T16E_CHANNEL2
#endif	// end of BIT_FIELD


// PWM Timer Compare Data B Register
#define	R16_T16E_CB(ch)						(volatile unsigned short *)(unsigned long)(T16E_BASE_ADDR+0x02+(ch*T16E_CHOFFSET))

#ifdef	BIT_FIELD
#define T16E_CB0							*(volatile unsigned short *)(BASE_ADDR+0x1302)
	#define T16E_CB0_T16ECB						T16E_CB0					// Compare data B

#ifdef	T16E_CHANNEL2
#define T16E_CB1							*(volatile unsigned short *)(BASE_ADDR+0x1362)
	#define T16E_CB1_T16ECB						T16E_CB1					// Compare data B
#endif	// end of T16E_CHANNEL2
#endif	// end of BIT_FIELD


// PWM TImer Counter Data Register
#define	R16_T16E_TC(ch)						(volatile unsigned short *)(unsigned long)(T16E_BASE_ADDR+0x04+(ch*T16E_CHOFFSET))

#ifdef	BIT_FIELD
#define T16E_TC0							*(volatile unsigned short *)(BASE_ADDR+0x1304)
	#define T16E_TC0_T16ETC						T16E_TC0					// Counter data

#ifdef	T16E_CHANNEL2
#define T16E_TC1							*(volatile unsigned short *)(BASE_ADDR+0x1364)
	#define T16E_TC1_T16ETC						T16E_TC1					// Counter data
#endif	// T16E_CHANNEL2
#endif	// end of BIT_FIELD


// PWM Timer Control Register
#define	R16_T16E_CTL(ch)					(volatile unsigned short *)(unsigned long)(T16E_BASE_ADDR+0x06+(ch*T16E_CHOFFSET))
	#define	INITOL_SFT							8
	#define	SELFM_SFT							6
	#define	R16_T16E_CTL_CBUFEN_SFT				5
	#define	INVOUT_SFT							4
	#define	CLKSEL_SFT							3
	#define	OUTEN_SFT							2
	#define	T16ERST_SFT							1
	#define	T16ERUN_SFT							0
	#define	INITOL								BIT(0x0001, INITOL_SFT)		// Initial Output Level
		#define	T16E_LOW							0x0000						// Low
		#define	T16E_HIGH							0x0001						// High
	#define	SELFM								BIT(0x0001, SELFM_SFT)		// Fine Mode Select
		#define	T16E_NORMAL							0x0000						// normal
		#define	T16E_FINE							0x0001						// fine
	#define	R16_T16E_CTL_CBUFEN					BIT(0x0001, R16_T16E_CTL_CBUFEN_SFT)		// Comparison Buffer Enable
		#define	T16E_DISABLE						0x0000						// disable
		#define	T16E_ENABLE							0x0001						// enable
	#define	INVOUT								BIT(0x0001, INVOUT_SFT)		// Inverse Output Control
		#define	T16E_INVERT							0x0001						// invert
	#define	CLKSEL								BIT(0x0001, CLKSEL_SFT)		// Input Clock Select
		#define	T16E_INTERNAL						0x0000						// internal
		#define	T16E_EXTERNAL						0x0001						// external
	#define	OUTEN								BIT(0x0001, OUTEN_SFT)		// Clock Output Enable
	#define	T16ERST								BIT(0x0001, T16ERST_SFT)	// Timer Reset
		#define	T16E_INVALID						0x0000						// invalid
		#define	T16E_RESET							0x0001						// reset
	#define	T16ERUN								BIT(0x0001, T16ERUN_SFT)	// Timer Run/Stop Control
		#define	T16E_STOP							0x0000						// stop
		#define	T16E_RUN							0x0001						// run
		#define	T16E_MODE_MASK						(INITOL | SELFM | R16_T16E_CTL_CBUFEN	 | INVOUT | CLKSEL | OUTEN)
																			// mode mask data

#ifdef	BIT_FIELD
#define T16E_CTL0							*(volatile unsigned short *)(BASE_ADDR+0x1306)
#define BF_T16E_CTL0						(*(volatile struct t16e_ctlBitF *)(BASE_ADDR+0x1306))
	#define T16E_CTL0_INITOL					BF_T16E_CTL0.initol			// Initial Output Level
	#define T16E_CTL0_SELFM						BF_T16E_CTL0.selfm			// Fine mode select
	#define T16E_CTL0_CBUFEN					BF_T16E_CTL0.cbufen			// Comparison buffer enable
	#define T16E_CTL0_INVOUT					BF_T16E_CTL0.invout			// Inverse output
	#define T16E_CTL0_CLKSEL					BF_T16E_CTL0.clksel			// Input clock select
	#define T16E_CTL0_OUTEN						BF_T16E_CTL0.outen			// Clock output enable
	#define T16E_CTL0_T16ERST					BF_T16E_CTL0.t16erst		// Timer reset
	#define T16E_CTL0_T16ERUN					BF_T16E_CTL0.t16erun		// Timer run/stop control

#ifdef	T16E_CHANNEL2
#define T16E_CTL1							*(volatile unsigned short *)(BASE_ADDR+0x1366)
#define BF_T16E_CTL1						(*(volatile struct t16e_ctlBitF *)(BASE_ADDR+0x1366))
	#define T16E_CTL1_INITOL					BF_T16E_CTL1.initol			// Initial Output Level
	#define T16E_CTL1_SELFM						BF_T16E_CTL1.selfm			// Fine mode select
	#define T16E_CTL1_CBUFEN					BF_T16E_CTL1.cbufen			// Comparison buffer enable
	#define T16E_CTL1_INVOUT					BF_T16E_CTL1.invout			// Inverse output
	#define T16E_CTL1_CLKSEL					BF_T16E_CTL1.clksel			// Input clock select
	#define T16E_CTL1_OUTEN						BF_T16E_CTL1.outen			// Clock output enable
	#define T16E_CTL1_T16ERST					BF_T16E_CTL1.t16erst		// Timer reset
	#define T16E_CTL1_T16ERUN					BF_T16E_CTL1.t16erun		// Timer run/stop control
#endif	// end of T16E_CHANNEL2
#endif	// end of BIT_FIELD


// PWM Timer Input Clock Select Register
#define	R16_T16E_CLK(ch)					(volatile unsigned short *)(unsigned long)(T16E_BASE_ADDR+0x08+(ch*T16E_CHOFFSET))
	#define	T16EDF_SFT							0
	#define	T16EDF								BIT(0x000f, T16EDF_SFT)		// Timer Input Clock Select

#ifdef	BIT_FIELD
#define T16E_CLK0							*(volatile unsigned short *)(BASE_ADDR+0x1308)
#define BF_T16E_CLK0						(*(volatile struct t16e_clkBitF *)(BASE_ADDR+0x1308))
	#define T16E_CLK0_T16EDF					BF_T16E_CLK0.t16edf			// Timer input clock select

#ifdef	T16E_CHANNEL2
#define T16E_CLK1							*(volatile unsigned short *)(BASE_ADDR+0x1368)
#define BF_T16E_CLK1						(*(volatile struct t16e_clkBitF *)(BASE_ADDR+0x1368))
	#define T16E_CLK1_T16EDF					BF_T16E_CLK1.t16edf			// Timer input clock select
#endif	// end of T16E_CHANNEL2
#endif	// end of BIT_FIELD


// PWM Timer Interrupt Mask Register
#define	R16_T16E_IMSK(ch)					(volatile unsigned short *)(unsigned long)(T16E_BASE_ADDR+0x0a+(ch*T16E_CHOFFSET))
	#define	CBIE_SFT							1
	#define	CAIE_SFT							0
	#define	CBIE								BIT(0x0001, CBIE_SFT)		// Compare B Interrupt Enable
	#define	CAIE								BIT(0x0001, CAIE_SFT)		// Compare A Interrupt Enable
		#define	T16E_INT_MASK						(CBIE | CAIE)				// interrupt mask data

#ifdef	BIT_FIELD
#define T16E_IMSK0							*(volatile unsigned short *)(BASE_ADDR+0x130a)
#define BF_T16E_IMSK0						(*(volatile struct t16e_imskBitF *)(BASE_ADDR+0x130a))
	#define T16E_IMSK0_CBIE						BF_T16E_IMSK0.cbie			// Compare B interrupt enable
	#define T16E_IMSK0_CAIE						BF_T16E_IMSK0.caie			// Compare A interrupt enable

#ifdef	T16E_CHANNEL2
#define T16E_IMSK1							*(volatile unsigned short *)(BASE_ADDR+0x136a)
#define BF_T16E_IMSK1						(*(volatile struct t16e_imskBitF *)(BASE_ADDR+0x136a))
	#define T16E_IMSK1_CBIE						BF_T16E_IMSK1.cbie			// Compare B interrupt enable
	#define T16E_IMSK1_CAIE						BF_T16E_IMSK1.caie			// Compare A interrupt enable
#endif	// end of T16E_CHANNEL2
#endif	// end of BIT_FIELD


// PWM Timer Interrupt Flag Register
#define	R16_T16E_IFLG(ch)					(volatile unsigned short *)(unsigned long)(T16E_BASE_ADDR+0x0c+(ch*T16E_CHOFFSET))
	#define	CBIF_SFT							1
	#define	CAIF_SFT							0
	#define	CBIF								BIT(0x0001, CBIF_SFT)		// Compare B Interrupt Flag
	#define	CAIF								BIT(0x0001, CAIF_SFT)		// Compare A Interrupt Flag
		#define	T16E_NOTOCCURRED					0x0000						// not occurred
		#define	T16E_OCCURRED						0x0001						// occurred

#ifdef	BIT_FIELD
#define T16E_IFLG0							*(volatile unsigned short *)(BASE_ADDR+0x130c)
#define BF_T16E_IFLG0						(*(volatile struct t16e_iflgBitF *)(BASE_ADDR+0x130c))
	#define T16E_IFLG0_CBIF						BF_T16E_IFLG0.cbif			// Compare B interrupt flag
	#define T16E_IFLG0_CAIF						BF_T16E_IFLG0.caif			// Compare A interrupt flag

#ifdef	T16E_CHANNEL2
#define T16E_IFLG1							*(volatile unsigned short *)(BASE_ADDR+0x136c)
#define BF_T16E_IFLG1						(*(volatile struct t16e_iflgBitF *)(BASE_ADDR+0x136c))
	#define T16E_IFLG1_CBIF						BF_T16E_IFLG1.cbif			// Compare B interrupt flag
	#define T16E_IFLG1_CAIF						BF_T16E_IFLG1.caif			// Compare A interrupt flag
#endif	// end of T16E_CHANNEL2
#endif	// end of BIT_FIELD


#endif	// end of T16E_H_
