/******************************************************************
 * t8f.h
 * 
 * 8-bit timer driver
 * 
 * Copyright(C) SEIKO EPSON CORPORATION 2009. All rights Reserved.
 *****************************************************************/

#ifndef T8F_H_
#define T8F_H_


#include <s1c176xx.h>


#ifdef	BIT_FIELD
/***********************************************
 ****** The Definition of bit field         ****
 ***********************************************/
struct t8f_clkBitF {
	unsigned int	t8df	: 4;
	unsigned int			: 12;
};

struct t8f_trBitF {
	unsigned int	tr		: 8;
	unsigned int			: 8;
};

struct t8f_tcBitF {
	unsigned int	tc		: 8;
	unsigned int			: 8;
};

struct t8f_ctlBitF {
	unsigned int	prun	: 1;
	unsigned int	preser	: 1;
	unsigned int			: 2;
	unsigned int	trmd	: 1;
	unsigned int			: 3;
	unsigned int	tfmd	: 4;
	unsigned int			: 4;
};

struct t8f_intBitF {
	unsigned int	t8if	: 1;
	unsigned int			: 7;
	unsigned int	t8ie	: 1;
	unsigned int			: 7;
};
#endif	// end of BIT_FIELD


/***********************************************
 ****** The Definition of base address      ****
 ***********************************************/
#define	T8F_BASE_ADDR						(BASE_ADDR+T8F_OFFSET)


/***********************************************
 ****** The Definition of 8-bit Timer **********
 ****** [T8F Ch0]                     **********
 ***********************************************/
// 8-bit Timer Ch.x Input Clock Select Register
#define	R16_T8F_CLK(ch)						(volatile unsigned short *)(unsigned long)(T8F_BASE_ADDR+0x00+(ch*T8F_CHOFFSET))
	#define	T8DF_SFT							0
	#define	T8DF								BIT(0x000f, T8DF_SFT)		// Timer Input Clock Select

#ifdef	BIT_FIELD
#define T8F_CLK0							*(volatile unsigned short *)(BASE_ADDR+0x0200)
#define BF_T8F_CLK0							(*(volatile struct t8f_clkBitF *)(BASE_ADDR+0x0200))
	#define T8F_CLK0_DF							BF_T8F_CLK0.t8df			// Timer input clock select

#define T8F_CLK1							*(volatile unsigned short *)(BASE_ADDR+0x0280)
#define BF_T8F_CLK1							(*(volatile struct t8f_clkBitF *)(BASE_ADDR+0x0280))
	#define T8F_CLK1_DF							BF_T8F_CLK1.t8df			// Timer input clock select
#endif	// end of BIT_FIELD


// 8-bit Timer Ch.x Reload Data Register
#define	R16_T8F_TR(ch)						(volatile unsigned short *)(unsigned long)(T8F_BASE_ADDR+0x02+(ch*T8F_CHOFFSET))
	#define	T8TR_SFT							0
	#define	T8TR								BIT(0x00ff, T8TR_SFT)		// 8-bit Timer Reload Data

#ifdef	BIT_FIELD
#define T8F_TR0								*(volatile unsigned short *)(BASE_ADDR+0x0202)
#define BF_T8F_TR0							(*(volatile struct t8f_trBitF *)(BASE_ADDR+0x0202))
	#define T8F_TR0_TR0							BF_T8F_TR0.tr				// 8-bit timer reload data

#define T8F_TR1								*(volatile unsigned short *)(BASE_ADDR+0x0282)
#define BF_T8F_TR1							(*(volatile struct t8f_trBitF *)(BASE_ADDR+0x0282))
	#define T8F_TR1_TR0							BF_T8F_TR1.tr				// 8-bit timer reload data
#endif	// end of BIT_FIELD


// 8-bit Timer Ch.x Counter Data Register
#define	R16_T8F_TC(ch)						(volatile unsigned short *)(unsigned long)(T8F_BASE_ADDR+0x04+(ch*T8F_CHOFFSET))
	#define	T8TC_SFT							0
	#define	T8TC								BIT(0x00ff, T8TC_SFT)		// 8-bit Timer Counter Data

#ifdef	BIT_FIELD
#define T8F_TC0								*(volatile unsigned short *)(BASE_ADDR+0x0204)
#define BF_T8F_TC0							(*(volatile struct t8f_tcBitF *)(BASE_ADDR+0x0204))
	#define T8F_TC0_TC							BF_T8F_TC0.tc				// 8-bit timer counter data

#define T8F_TC1								*(volatile unsigned short *)(BASE_ADDR+0x0284)
#define BF_T8F_TC1							(*(volatile struct t8f_tcBitF *)(BASE_ADDR+0x0284))
	#define T8F_TC1_TC							BF_T8F_TC1.tc				// 8-bit timer counter data
#endif	// end of BIT_FIELD


// 8-bit Timer Ch.x Control Register
#define	R16_T8F_CTL(ch)						(volatile unsigned short *)(unsigned long)(T8F_BASE_ADDR+0x06+(ch*T8F_CHOFFSET))
	#define	T8TFMD_SFT							8
	#define	T8TRMD_SFT							4
	#define	T8PRESER_SFT						1
	#define	T8PRUN_SFT							0
	#define	T8TFMD								BIT(0x000f, T8TFMD_SFT)		// Fine Mode Setup
	#define	T8TRMD								BIT(0x0001, T8TRMD_SFT)		// Count Mode Select
		#define	T8F_REPEAT							0x0000						// repeat
		#define	T8F_ONESHOT							0x0001						// one shot
	#define	T8PRESER							BIT(0x0001, T8PRESER_SFT)	// Timer Reset
		#define	T8F_IGNORED							0x0000						// ignored
		#define	T8F_RESET							0x0001						// reset
	#define	T8PRUN								BIT(0x0001, T8PRUN_SFT)		// Timer Run/Stop Control
		#define	T8F_STOP							0x0000						// stop
		#define	T8F_RUN								0x0001						// run

#ifdef	BIT_FIELD
#define T8F_CTL0							*(volatile unsigned short *)(BASE_ADDR+0x0206)
#define BF_T8F_CTL0							(*(volatile struct t8f_ctlBitF *)(BASE_ADDR+0x0206))
	#define T8F_CTL0_TFMD						BF_T8F_CTL0.tfmd			// Fine mode setup
	#define T8F_CTL0_TRMD						BF_T8F_CTL0.trmd			// Count mode select
	#define T8F_CTL0_PRESER						BF_T8F_CTL0.preser			// Timer reset
	#define T8F_CTL0_PRUN						BF_T8F_CTL0.prun			// Timer run/stop control

#define T8F_CTL1							*(volatile unsigned short *)(BASE_ADDR+0x0286)
#define BF_T8F_CTL1							(*(volatile struct t8f_ctlBitF *)(BASE_ADDR+0x0286))
	#define T8F_CTL1_TFMD						BF_T8F_CTL1.tfmd			// Fine mode setup
	#define T8F_CTL1_TRMD						BF_T8F_CTL1.trmd			// Count mode select
	#define T8F_CTL1_PRESER						BF_T8F_CTL1.preser			// Timer reset
	#define T8F_CTL1_PRUN						BF_T8F_CTL1.prun			// Timer run/stop control
#endif	// end of BIT_FIELD


// 8-bit Timer Ch.x Interrupt Control Register
#define	R16_T8F_INT(ch)						(volatile unsigned short *)(unsigned long)(T8F_BASE_ADDR+0x08+(ch*T8F_CHOFFSET))
	#define	T8IE_SFT							8
	#define	T8IF_SFT							0
	#define	T8IE								BIT(0x0001, T8IE_SFT)		// 8-bit Timer Interrupt Enable
		#define T8F_DISABLE							0x0000						// disable
		#define T8F_ENABLE							0x0001						// enable
	#define	T8IF								BIT(0x0001, T8IF_SFT)		// 8-bit Timer Interrupt Flag
		#define T8F_NOTOCCURRED						0x0000						// not occurred
		#define T8F_OCCURRED						0x0001						// occurred

#ifdef	BIT_FIELD
#define T8F_INT0							*(volatile unsigned short *)(BASE_ADDR+0x0208)
#define BF_T8F_INT0							(*(volatile struct t8f_intBitF *)(BASE_ADDR+0x0208))
	#define T8F_INT0_T8IE						BF_T8F_INT0.t8ie			// 8-bit Timer Interrupt enable
	#define T8F_INT0_T8IF						BF_T8F_INT0.t8if			// 8-bit Timer Interrupt flag

#define T8F_INT1							*(volatile unsigned short *)(BASE_ADDR+0x0288)
#define BF_T8F_INT1							(*(volatile struct t8f_intBitF *)(BASE_ADDR+0x0288))
	#define T8F_INT1_T8IE						BF_T8F_INT1.t8ie			// 8-bit Timer Interrupt enable
	#define T8F_INT1_T8IF						BF_T8F_INT1.t8if			// 8-bit Timer Interrupt flag
#endif	// end of BIT_FIELD


#endif	// end of T8F_H_
